package morrowind;


  /**
   * An XmlHandlerException is thrown when a static method in XmlHandler encounters an
   * unrecoverable error.
   *
   * @see      pixie.xml.XmlHandler
   * @author   Andy Joel
   * @version  1.0 June 2003
   */


public class XmlHandlerException extends Exception {

      /**
       * Indicates an error that has not been specified.
       */
    public static final int UNSPECIFIED = 0;

      /**
       * Indicates an error in the XML code, such as no terminating tag found.
       */
    public static final int BAD_XML = 1;

      /**
       * Indicates an error, with the required XML element or value not being found.
       */
    public static final int NOT_FOUND = 2;

      /**
       * Indicates an error in the format of a value (eg text found, integer required).
       */
    public static final int BAD_ARGUMENT = 3;

      /**
       * Indicates an error trying to instantiate a pixie.xml.XmlUser (that is to say unrelated to the rules of XML).
       */
    public static final int BAD_INSTANTIATION = 4;

    private static final String[] errors = {
        "", "Badly formed XML", "Value or element not found", "Value format error", "Instatiation error",
    };
    private int errorCode;


    /**
     * Constructs an <code>XmlHandlerException</code> with <code>null</code>
     * as its error detail message and <code>UNSPECIFIED</code> as the eror
     * code.
     */
    public XmlHandlerException() {
        super();
        errorCode = UNSPECIFIED;
    }

    /**
     * Constructs an <code>XmlHandlerException</code> with the specified detail
     * message. The error message string <code>msg</code> can later be
     * retrieved by the <code>{@link java.lang.Throwable#getMessage}</code>
     * method of class <code>java.lang.Throwable</code>.
     * <code>UNSPECIFIED</code> is used as the eror
     * code.
     *
     * @param   msg   the detail message.
     */
    public XmlHandlerException(String msg) {
        super(msg);
        errorCode = UNSPECIFIED;
    }

    /**
     * Constructs an <code>XmlHandlerException</code> with the specified detail
     * message and error code. The error message string <code>msg</code> can later be
     * retrieved by the <code>{@link java.lang.Throwable#getMessage}</code>
     * method of class <code>java.lang.Throwable</code>, the error code
     * by getErrorCode().
     * <code>UNSPECIFIED</code> is used as the eror
     * code.
     *
     * @param   msg   the detail message.
     * @param   errorCode   the error code.
     */
    public XmlHandlerException(String msg, int errorCode) {
        super(msg);
        this.errorCode = errorCode;
    }

    /**
     * Gets the error code of this exception.
     *
     * @return The error code
     */
    public int getErrorCode() {
        return errorCode;
    }

    /**
     * Gets the detailed error message of this exception.
     * If the error code is not <code>UNSPECIFIED</code>, a textual interpetation of
     * the error code is put at the front of the message.
     *
     * @return The error message
     */
    public String getMessage() {
        return (errorCode == UNSPECIFIED) ? super.getMessage() : errors[errorCode] + ": " + super.getMessage();
    }
}
