package morrowind;

/**
 * This interface provides a common framework for classes that will be
 * converted to and from XML.
 *
 * @author Andy Joel
 * @version 1.0 28/Dec/01
 */

public interface XmlUser {

    /**
     * Method to initialise the object from an XML formatted
     * <code>String</code>. This method would be called after the constructor.
     * Initialising in a separate method allows the API user to employ
     * reflection to construct a class, though the no parameter constructor.
     *
     * @param   xmlString      The string to interprete.
     */
    public void fromXml(String xmlString) throws XmlHandlerException;

    /**
     * Method to retrieve the object in a <code>String</code>, formatted
     * according to XML. It is up to the subclass to ensure that the XML
     * produced is valid and conforms to the DTD, and moreover, can be handled
     * by the <code>init(String)</code> method.
     *
     * @return                The object instance in XML format.
     */
    public String toXml();

    /**
     * Returns the tag name for the XmlUser.
     *
     * @return                The object's tag as a String.
     */
    public String getTag();
}

